DateSelectorYearWidget | django_cradmin API Document

    import DateSelectorYearWidget from 'django_cradmin/scripts/django_cradmin/widgets/DateSelectorYearWidget.jsx'

public class | source

# DateSelectorYearWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → DateSelectorYearWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Method Summary

Public Methods
public | afterInitializeAllWidgets() |
public | destroy() |
public | useAfterInitializeAllWidgets(): boolean |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Methods

### public afterInitializeAllWidgets() source

### public destroy() source

### public useAfterInitializeAllWidgets(): boolean source

#### Return:

boolean